==> tea_32.0.1.orig.tar.bz2: tea-32.0.1/fman.h <==
 /**************************************************************************
 *   Copyright (C) 2007-2010 by Peter Semiletov                            *
 *   peter.semiletov@gmail.com                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef FMAN_H
#define FMAN_H

#include <QtGui>

#include "tzipper.h"


class CTreeView;


class CTvFmanKeyPressEater: public QObject
{
  Q_OBJECT

signals:

  void backspacePressed();

protected:

  bool eventFilter (QObject *obj, QEvent *event);
};


class CFMan: public QObject
{
  Q_OBJECT

public:

  CTvFmanKeyPressEater *evfilter;
  CZipper zipper;
  
  QStandardItemModel *model;
  CTreeView *tree_view;
  QList <QFileInfo> list;
  
  QDir dir;
    
  CFMan (QObject *parent = 0);
  ~CFMan();

  void add_entry (const QFileInfo &fi);
  void append_dot_entry (const QString &fname);

  const QModelIndex index_from_name (const QString &name);
  const QModelIndex index_from_idx (int idx);
  int get_sel_index();
  
  void nav (const QString &path);

  QString get_sel_fname();
  QStringList get_sel_fnames();

public slots:

  void tv_activated (const QModelIndex &index);
  void refresh();
  void dir_up();
  void cb_fman_currentChanged (const QModelIndex &current, const QModelIndex &previous);

signals:

 void file_activated (const QString &path);
 void dir_changed (const QString &path);
 void current_file_changed (const QString &path, const QString &just_name);
};


class CTreeView: public QTreeView
{
public: 
   
  CFMan *fman; 

protected:
  
  void mouseMoveEvent (QMouseEvent *event);
};

#endif

==> tea_33.1.0.orig.tar.bz2: tea-33.1.0/fman.h <==
 /**************************************************************************
 *   Copyright (C) 2007-2010 by Peter Semiletov                            *
 *   peter.semiletov@gmail.com                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef FMAN_H
#define FMAN_H

//#include <QtGui>

#include <QObject>
#include <QStandardItemModel>
#include <QTreeView>
#include <QHeaderView>
#include <QDir>
#include <QDrag>
//#include <QMimeType>


#include "tzipper.h"


class CTreeView;


class CTvFmanKeyPressEater: public QObject
{
  Q_OBJECT

signals:

  void backspacePressed();

protected:

  bool eventFilter (QObject *obj, QEvent *event);
};


class CFMan: public QObject
{
  Q_OBJECT

public:

  CTvFmanKeyPressEater *evfilter;
  CZipper zipper;
  
  QStandardItemModel *model;
  CTreeView *tree_view;
  QList <QFileInfo> list;
  
  QDir dir;
    
  CFMan (QObject *parent = 0);
  ~CFMan();

  void add_entry (const QFileInfo &fi);
  void append_dot_entry (const QString &fname);

  const QModelIndex index_from_name (const QString &name);
  const QModelIndex index_from_idx (int idx);
  int get_sel_index();
  
  void nav (const QString &path);

  QString get_sel_fname();
  QStringList get_sel_fnames();

public slots:

  void tv_activated (const QModelIndex &index);
  void refresh();
  void dir_up();
  void cb_fman_currentChanged (const QModelIndex &current, const QModelIndex &previous);

signals:

 void file_activated (const QString &path);
 void dir_changed (const QString &path);
 void current_file_changed (const QString &path, const QString &just_name);
};


class CTreeView: public QTreeView
{
public: 
   
  CFMan *fman; 

protected:
  
  void mouseMoveEvent (QMouseEvent *event);
};

#endif
